==> chemistry-opencmis-client-impl-0.8.0-sources.jar: org/apache/chemistry/opencmis/client/runtime/util/CollectionPageIterable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.client.runtime.util;


/**
 * Iterable for a CMIS Collection Page
 */
public class CollectionPageIterable<T> extends AbstractIterable<T> {

    /**
     * Construct
     *
     * @param pageFetcher
     */
    public CollectionPageIterable(AbstractPageFetcher<T> pageFetcher) {
        this(0, pageFetcher);
    }

    /**
     * Construct
     *
     * @param position
     * @param pageFetcher
     */
    protected CollectionPageIterable(long position, AbstractPageFetcher<T> pageFetcher) {
        super(position, pageFetcher);
    }

    @Override
    protected AbstractIterator<T> createIterator() {
        return new CollectionPageIterator<T>(getSkipCount(), getPageFetcher());
    }
}

==> chemistry-opencmis-client-impl-1.1.0-sources.jar: org/apache/chemistry/opencmis/client/runtime/util/CollectionPageIterable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.client.runtime.util;

import org.apache.chemistry.opencmis.client.api.ItemIterable;

/**
 * Iterable for a CMIS Collection Page.
 */
public class CollectionPageIterable<T> extends AbstractIterable<T> {

    /**
     * Constructor.
     */
    public CollectionPageIterable(AbstractPageFetcher<T> pageFetcher) {
        this(0, pageFetcher);
    }

    /**
     * Constructor.
     */
    protected CollectionPageIterable(long position, AbstractPageFetcher<T> pageFetcher) {
        super(position, pageFetcher);
    }

    @Override
    public ItemIterable<T> skipTo(long position) {
        return new CollectionPageIterable<T>(position, getPageFetcher());
    }

    @Override
    protected AbstractIterator<T> createIterator() {
        return new CollectionPageIterator<T>(getSkipCount(), getPageFetcher());
    }
}
